# Twitter Variations

This is a package to convert twitter variation into english letters. People usually use different characters to represent their words. This package will help machines understand the meaning of words by bringing them back to normal english characters.
